import { enableAnrDetection as enableNodeAnrDetection } from '@sentry/node';
import { WebContents } from 'electron';
import { RendererStatus } from '../common';
/** Are we currently running in the ANR child process */
export declare function isAnrChildProcess(): boolean;
/** Creates a renderer ANR status hook */
export declare function createRendererAnrStatusHandler(): (status: RendererStatus, contents: WebContents) => void;
/**
 * **Note** This feature is still in beta so there may be breaking changes in future releases.
 *
 * Starts a child process that detects Application Not Responding (ANR) errors.
 *
 * It's important to await on the returned promise before your app code to ensure this code does not run in the ANR
 * child process.
 *
 * ```js
 * import { init, enableMainProcessAnrDetection } from '@sentry/electron';
 *
 * init({ dsn: "__DSN__" });
 *
 * // with ESM + Electron v28+
 * await enableMainProcessAnrDetection({ captureStackTrace: true });
 * runApp();
 *
 * // with CJS
 * enableMainProcessAnrDetection({ captureStackTrace: true }).then(() => {
 *   runApp();
 * });
 * ```
 */
export declare function enableMainProcessAnrDetection(options: Parameters<typeof enableNodeAnrDetection>[0]): Promise<void>;
//# sourceMappingURL=anr.d.ts.map