const dns = require('dns');

const { lookup } = require('./config');

jest.mock('dns');

test('lookup', async () => {
  let records = [];
  dns.resolveTxt.mockImplementation((domain, cb) => {
    if (domain === 'error') {
      cb(new Error('resolve error'), null);
    } else {
      cb(null, records);
    }
  });

  await expect(lookup('error')).rejects.toThrow('resolve error');
  await expect(lookup('foo')).rejects.toThrow('no records found at domain');

  records = [['{}']];
  await expect(lookup('foo')).rejects.toThrow('Unexpected end of JSON input');

  records = [[btoa('{}')]];
  await expect(lookup('foo')).resolves.toEqual({
    server: '',
    site: '',
    delay: 5,
    interval: 300,
    notify: true,
  });

  records = [[btoa('{ "server": "https://update.example.com", "delay": 50}')]];
  await expect(lookup('foo')).resolves.toEqual({
    server: 'https://update.example.com',
    site: '',
    delay: 50,
    interval: 300,
    notify: true,
  });
});
