const dns = require('dns');
const electron = require('electron');

const update = require('./main');
const { sleep } = require('./utils');

jest.mock('dns');

jest.mock('electron', () => {
  return {
    app: {
      on: jest.fn(),
      isReady: jest.fn(),
      getVersion() {
        return '1.2.3';
      },
    },
  };
});

jest.mock('process');

jest.mock('electron-squirrel-startup');

test('update', async () => {
  let ready = false;
  electron.app.isReady.mockImplementation(() => ready);
  electron.app.on.mockImplementation((event, cb) => {
    if (event === 'ready') {
      ready = true;
      cb();
    }
  });

  let records = [];
  dns.resolveTxt.mockImplementation((domain, cb) => {
    if (domain === 'error') {
      cb('resolve error', null);
    } else {
      cb(null, records);
    }
  });

  /* Config Error */

  let reporter = jest.fn();
  await update('error', reporter);
  await sleep(100);
  expect(reporter).toBeCalledWith('resolve error');

  /* Valid Config */

  records = [[btoa('{ "server": "https://update.example.com", "delay": 50}')]];
  reporter = jest.fn();
  await update('foo', reporter);
  await sleep(100);
  expect(reporter).not.toBeCalled();
});
