const { app, dialog, shell } = require('electron');
const fetch = require('node-fetch');

const { retry } = require('./utils');
const pkg = require('./package.json');

module.exports.manualUpdate = function (server = '', site = '', interval = 300, reporter = () => {}) {
  retry(interval * 1000, async () => {
    // log info
    console.log('comet: manual: checking for update');

    // check for update
    let res;
    try {
      res = await fetch(`${server}/${process.platform}-${process.arch}/${app.getVersion()}`, {
        headers: {
          'User-Agent': `comet-electron (${pkg.version}, ${process.platform}, ${process.arch})`,
        },
      });
    } catch (err) {
      reporter(err);
      console.log('comet: manual: unable to contact update server:', err);
      return false;
    }

    // check code
    if (res.status === 204) {
      console.log('comet: manual: no update available');
      return false;
    } else if (res.status !== 200) {
      reporter(new Error('invalid response from server: ' + res));
      console.log('comet: manual: invalid response from update server:', res);
      return false;
    }

    // get url and version
    let data;
    try {
      data = await res.json();
    } catch (err) {
      reporter(err);
      console.log('comet: manual: unable to parse response:', err);
      return false;
    }

    // get params
    const { url, name: version, notes, pub_date: published } = data;

    // log info
    console.log('comet: manual: update available:', version, notes, published, url);

    // notify user about update
    const { response } = await dialog.showMessageBox({
      type: 'info',
      title: 'Application Update',
      message: `Version ${version} is available.`,
      detail: 'Download and install the new version now.',
      buttons: ['Download', 'Skip'],
      defaultId: 0,
    });

    // check response
    if (response === 0) {
      shell.openExternal(site || url).then();
    }

    return true;
  }).then();
};
