const { app } = require('electron');
const path = require('path');
const { spawn } = require('child_process');

module.exports = function runBroker(port, started, failed) {
  // get arch
  const arch = {
    x64: 'amd64',
    arm64: 'arm64',
  }[process.arch];

  // get binary
  let binary;
  switch (process.platform) {
    case 'darwin':
      binary = `shiftr-io-cli-darwin-${arch}`;
      break;
    case 'win32':
      binary = `shiftr-io-cli-windows-${arch}.exe`;
      break;
    case 'linux':
      binary = `shiftr-io-cli-linux-${arch}`;
      break;
  }

  // get binary path
  const binaryPath = path.join(app.getAppPath(), 'bin', binary);

  // spawn process
  const proc = spawn(binaryPath, ['broker', `--mqtt=${port}`, `--http=${port + 1}`], {
    env: Object.assign({}, process.env, { SH_DESKTOP: 'true' }),
  });

  // collect output
  let output = '';

  // relay output and await start
  proc.stdout.on('data', (data) => {
    console.log(`broker stdout: ${data}`);

    // check if http endpoint has started
    if (data.includes('Running at')) {
      setTimeout(started, 100);
    }

    // append output
    output += data.toString();
  });

  // relay and collect errors
  proc.stderr.on('data', (data) => {
    console.log(`broker stderr: ${data}`);

    // append output
    output += data.toString();
  });

  // prepare flags
  let running = true;
  let exited = false;

  // handle close
  proc.on('close', () => {
    // set flag
    running = false;

    // check if exit
    if (exited) {
      return;
    }

    // handle error
    if (output.includes('already in use')) {
      failed('used-ports');
    } else if (output.length > 0) {
      failed(output || 'Unable to start process.');
    }
  });

  // ensure quit
  process.on('exit', () => {
    // set flag
    exited = true;

    // kill if running
    if (running) {
      running = false;
      proc.kill();
    }
  });
};
